@@ -12,7 +12,8 @@ def pytest_addoption(parser):
     """
     adds the option to write --file=<your path to connector.py>
     """
-    parser.addoption("--file", action="store", default="absolute path to the connector script to run")
+    parser.addoption("--lib-path", action="store", default="absolute path to the conftest file from the root of the "
+                                                           "project")
     parser.addoption("--env", action="store", default="absolute path to the env that holds the variables used to test")
     parser.addoption(
         "--source", action="store_true", default=False, help="run source tests"
@@ -22,6 +23,19 @@ def pytest_addoption(parser):
     )
 
 
+@pytest.fixture(scope="session")
+def root_dir():
+    return os.path.dirname(".env.credentials")
+
+
+@pytest.fixture(scope="session")
+def add_root_dir_to_path(root_dir):
+    path = os.path.abspath(os.path.join(os.path.dirname(__file__), root_dir))
+    print(path)
+    if path not in sys.path:
+        sys.path.insert(1, path)
+
+
 @pytest.fixture(scope="session", autouse=True)
 def copy_ini_to_root():
     shutil.copy(os.path.join(os.path.dirname(__file__), "pytest.txt"),
@@ -30,23 +44,18 @@ def copy_ini_to_root():
 
 @pytest.fixture(scope="session")
 def module_name(pytestconfig):
-    return pytestconfig.getoption("file")
+    return pytestconfig.getoption("lib-path")
 
 
 @pytest.fixture(scope="session",
                 autouse=True)
-def connector_class():
+def connector_class(root_dir):
     """ This takes in the connector file name and tries to import it """
     try:
-        path = os.path.abspath(os.path.join(os.path.dirname(__file__), r"..\\..\\..\\..\\"))
-        print(path)
-        if not path in sys.path:
-            sys.path.insert(1, path)
         import src.connector as _conn
         return _conn
     except Exception:
-        print("Error: cannot locate Connector class in session <session name>")
-        exit(1)
+        raise Exception("Error: cannot locate Connector class in session <session name>")
 
 
 @pytest.fixture(scope="session")
